@@ -27,7 +27,16 @@ CNfsAppUi::ConstructL()
       break;
   fnb.SetLength(l+1);
   fnb.Append(_L("nfsclient.exe"));
+#if 0
   EikDll::StartExeL(fnb);
+#else
+ RProcess pr;
+ if(pr.Create(fnb,fnb) == KErrNone)
+   {
+     pr.Resume();
+     pr.Close();
+   }
+#endif
 
   User::Exit(0);
 }
