@@ -3,6 +3,9 @@
 //
 // some history
 //
+// 5.18    05. May 2005   rkoenig   Changing the version number
+// 2.9     ????????????   rkoenig   A920/925 keys added, async write disabled
+// 2.8     22. Jan 2004   rkoenig   BT Infoprint removed, XXX flush
 // 2.7     28. Dec 2003   rkoenig   UTF8, BT infoprint
 // 2.6     04. Apr 2003   rkoenig   Higher timeout (8K blocksize)
 // 2.5     04. Apr 2003   rkoenig   Tcpip port
@@ -20,7 +23,9 @@
 #include <f32file.h>
 #include <c32comm.h>
 #include <w32std.h>
+#if !defined(_SERIES60) && !defined(_SERIES80)
 #include <plpsess.h>
+#endif
 #ifdef _BLUETOOTH
 #include "rfcomm.h"
 #endif
@@ -31,30 +36,31 @@
 #include <stdarg.h>
 #include <stdio.h>
 #include <stdarg.h>
+#include "util.h"
+#include "../../nfsd/version.h"
 
 
 #define BLOCKSIZE 8192
 #define CMDBUF 256
 #define NCONFIG 10
+
 #define debug0(l,a)       if(gd->debug>=l) gd->cons->Printf(_L(a))
 #define debug1(l,a,b)     if(gd->debug>=l) gd->cons->Printf(_L(a), b)
 #define debug2(l,a,b,c)   if(gd->debug>=l) gd->cons->Printf(_L(a), b, c)
 
 #if defined(_UNICODE)
 # define CHAR TUint16
-# define _CL(a, b) (const TUint16 *)char2wchar(a, b)
+# define _CL(a, b) (TUint16 *)char2wchar(a, b)
 # define _C(a, b) TPtrC(_CL(a, b))
 # define _c(a, b) wchar2char(a.Ptr(), b, a.Length())
 #else // _UNICODE
 # define CHAR char
 # define _CL(a, b) (unsigned char *)a
 # define _C(a, buf) _L(a)
-# define _c(a, b) (char *)a.Ptr()
+# define _c(a, b) char2char((char *)a.Ptr(), b, a.Length())
 #endif // _UNICODE
 
 
-
-
 typedef enum {
   T_SERIAL,
   T_IRDA,
@@ -92,9 +98,10 @@ struct global_data {
   // buffers
 #ifdef _UNICODE
   CHAR ubuf1[CMDBUF], ubuf2[CMDBUF];
-  char cbuf[CMDBUF];
 #endif
 
+  char cbuf[CMDBUF];
+
   int gb_idx; ///< global buffer index
 
   char asyncbuf[BLOCKSIZE];
@@ -223,6 +230,22 @@ wchar2char(const CHAR *in, char *out, int len) // UCS2 -> UTF8
   out[j] = 0;
   return out;
 }
+
+
+#else
+
+char *
+char2char(const char *in, char *out, int len)
+{
+  char *o = out;
+
+  while(len--)
+    *o++ = *in++;
+  *o = 0;
+
+  return out;
+}
+
 #endif
 
 
@@ -290,7 +313,6 @@ public:
 
 /////////////////////////////////////////////
 // Reading from the serial line, returning a byte from a buffer
-// Handling software flowcontrol if #defined
 int
 GetByte(struct global_data *gd)
 {
@@ -329,7 +351,6 @@ DoRead(struct global_data *gd, char *buf, int len)
 
 /////////////////////////////////////////////
 // Writing data
-// Handling software flowcontrol if #defined
 int
 DoWrite(struct global_data *gd, const char *buf, int len)
 {
@@ -372,11 +393,9 @@ doStat(struct global_data *gd,
   RFs *iFs = gd->iFs;
   TEntry e;
   int r, i, l;
-#ifdef _UNICODE
   CHAR lbuf[KMaxFileName];
-#endif
 
-  TPtrC fn(_CL(fname, lbuf));
+  TPtr fn(_CL(fname, lbuf), strlen(fname), KMaxFileName);
   debug1(2, " Stat |%S| ", &fn);
   if(!isvolume)
     {
@@ -398,7 +417,7 @@ doStat(struct global_data *gd,
     {
       CDir *cdir = 0;
       rbuf[2] = (1<<4);
-      fname[namelen] = '\\'; fname[namelen+1] = 0;
+      fn.Append('\\');
       r = iFs->GetDir(fn, KEntryAttMatchMask, ESortNone, cdir);
       l = 0;
       for(i = 0; i < cdir->Count(); i++)
@@ -454,7 +473,7 @@ DoReq(struct global_data *gd, int len)
   cmd = buf[len-1];
 
   TPtrC fn(_CL(buf+1, gd->ubuf1));
-  debug2(2, "CMD %d for |%S|: ", cmd, &fn);
+  //debug2(2, "CMD %d for |%s|: ", cmd, gd->ubuf1);
 
   if(gd->rfilename[0] && cmd != 4)// Close the read handle, if not reading.
     {
@@ -593,7 +612,7 @@ read_done:
 	  }
 	repchar = r ? 'N' : 'n';
 	break;
-case 8:	// RmDir
+      case 8:	// RmDir
         buf[*buf+1] = '\\'; buf[*buf+2] = 0;
         r = iFs->RmDir(_C(buf+1, gd->ubuf1));
 	repchar = r ? 'Z' : 'z';
@@ -624,62 +643,50 @@ case 8:	// RmDir
 	gd->asyncop = 0;
 	gd->asyncoffset = -1;
 
-	if(!r && dlen == BLOCKSIZE)	// Async writing in the background.
+	last_block = (dlen < BLOCKSIZE); // used later
+	while(dlen)
 	  {
-	    if((r = DoRead(gd, gd->asyncbuf, dlen)))
+	    int l = dlen > BLOCKSIZE ? BLOCKSIZE : dlen;
+	    if((r = DoRead(gd, buf, l)))
 	      goto write_done;
 
-	    TPtrC8 p((unsigned char *)gd->asyncbuf, dlen);
-            gd->iWFile->Write(off, p, dlen, gd->asyncst);
-	    gd->asyncop = 1;
-	  }
-	else
-	  {
-	    last_block = (dlen < BLOCKSIZE); // used later
-	    while(dlen)
+	    TPtrC8 p((unsigned char *)buf, l);
+	    if(!r)
 	      {
-		int l = dlen > BLOCKSIZE ? BLOCKSIZE : dlen;
-		if((r = DoRead(gd, buf, l)))
-		  goto write_done;
-
-		TPtrC8 p((unsigned char *)buf, l);
-		if(!r)
-		  {
-		    r = gd->iWFile->Write(off, p, l);
-		    debug2(3, " WF(%d)=%d ", l, r);
-		    off += l;
-		  }
-		dlen -= l;
+		r = gd->iWFile->Write(off, p, l);
+		debug2(3, " WF(%d)=%d ", l, r);
+		off += l;
 	      }
+	    dlen -= l;
+	  }
 
 write_done:
-	    if(r && gd->wfilename[0])
-	      {
-		gd->iWFile->Close();
-		gd->wfilename[0] = 0;
-	      }
+	if(r && gd->wfilename[0])
+	  {
+	    gd->iWFile->Close();
+	    gd->wfilename[0] = 0;
+	  }
 
-	    if(last_block)
-	      {
-		if(gd->wfilename[0])
-		  gd->iWFile->Close();
-		gd->wfilename[0] = 0;
+	if(last_block)
+	  {
+	    if(gd->wfilename[0])
+	      gd->iWFile->Close();
+	    gd->wfilename[0] = 0;
 
-		/** auto-execution of .exe's - last block is *probably* less
-		 *  than BLOCKSIZE :) press key 'x' to toggle on/off
-		 */
-		if(gd->auto_exec)
+	    /** auto-execution of .exe's - last block is *probably* less
+	     *  than BLOCKSIZE :) press key 'x' to toggle on/off
+	     */
+	    if(gd->auto_exec)
+	      {
+		if(fn.MatchF(_L("*.exe")) != KErrNotFound)
 		  {
-		    if(fn.MatchF(_L("*.exe")) != KErrNotFound)
-		      {
-			debug1(1, "\nexecuting file '%S'", &fn);
-			RProcess p;
-			p.Create(fn, KNullDesC);
-			p.Resume();
-			p.Close();
-		      }
-
+		    debug1(1, "\nexecuting file '%S'", &fn);
+		    RProcess p;
+		    p.Create(fn, KNullDesC);
+		    p.Resume();
+		    p.Close();
 		  }
+
 	      }
 	  }
 	
@@ -719,6 +726,9 @@ write_done:
 	repchar = r ? 'F' : 'f';
 	break;
       default:
+	// Oops. Lets read the garbage away. Takes at least 3 seconds!
+        while(DoRead(gd, buf2, sizeof(buf2)) != KErrTimedOut)
+	  ;
         repchar = 'X'; r = 1;
         break;
     }
@@ -884,10 +894,11 @@ mainL()
     return 0;
 
   gd->cons =
-  	Console::NewL(KPgmName, TSize(KDefaultConsWidth, KDefaultConsHeight));
+  	//Console::NewL(KPgmName, TSize(KDefaultConsWidth, KDefaultConsHeight));
+  	Console::NewL(KPgmName, TSize(KDefaultConsWidth, 10));
   CConsoleBase *cons = gd->cons;
   cons->Printf(_L("Welcome to nfsclient\n"));
-  cons->Printf(_L("Ver:2.7, Licence:GPL\n\n"));
+  cons->Printf(_L("Ver:" VERSION ", Licence:GPL\n\n"));
 #if defined(_UIQ)
   cons->Printf(_L("- Scroll down for switching i/o\n"));
   cons->Printf(_L("  interfaces (Bluetooth/IrDA)\n"));
@@ -934,6 +945,7 @@ mainL()
       }
 
 
+#if !defined(_SERIES60) && !defined(_SERIES80)
   /**
    * try to stop PLP first (which hoggs COMM::0)
    */
@@ -946,6 +958,7 @@ mainL()
       debug1(1, "[ret=%d]\n", r);
       link.Close();
     }
+#endif
   
 
 
@@ -991,6 +1004,7 @@ mainL()
 		return 0;
 #ifdef _UIQ
 	      case EKeyDevice1:		// EQuartzKeyTwoWayUp
+	      case 63558:		// Motorola 920 / 925
 #endif
 	      case 'd':
 		gd->debug = (gd->debug+1) % 4;
@@ -1006,6 +1020,7 @@ mainL()
 #endif
 #ifdef _UIQ
 	      case EKeyDevice2:		// EQuartzKeyTwoWayDown
+	      case 63559:		// Motorola 920 / 925
 #endif
 	      case 'p':
 		SetCommPort(iServer, gd, ++port);
@@ -1014,7 +1029,7 @@ mainL()
 	        break;
 	      case 'g':			// 7650
 	      case 'h':
-  		cons->Printf(_L("\nVer:2.7, Licence:GPL\n"));
+  		cons->Printf(_L("\nVer:" VERSION ", Licence:GPL\n"));
   		cons->Printf(_L("Keyboard commands:\n"));
 		cons->Printf(_L("  q/t (exit)\n"));
 		cons->Printf(_L("  d   (debug on/off)\n"));
@@ -1035,7 +1050,9 @@ mainL()
       if(rs_s != KRequestPending)
 	{
 	  if(rs_s == KErrAbort)
-	    gd->iCommPort->Cancel();
+	    {
+	      gd->iCommPort->Cancel();
+	    }
 	  else if(rs_s != KErrNone)
 	    {
 	      gd->iCommPort->Cancel();
