@@ -28,11 +28,11 @@ extern void nfs_program_2();
 
 char *dev  = DDEV, *user, *dir  = DDIR;
 int speed = 115200;
-int timeout = 3000;	// 3 seconds
+int timeout = 5000;	// 5 seconds
 
 int psionfd, gmtoffset, debug, exiting, psion_alive, dowakeup = 0, old_nfsc = 0,
     query_cache = 0, background = 1, series5 = 0, soft_flow = 0, no_flow = 0,
-    tcp = 0;
+    tcp = 0, nfsblock = PBUFSIZE;
 fattr root_fattr = {
   NFDIR, 0040500, 1, 0, 0,
   BLOCKSIZE, BLOCKSIZE, FID, 1, FID, 1,
@@ -94,6 +94,7 @@ main(ac, av)
       else if(!strcmp(av[1], "-softflow")){ soft_flow = 1; }
       else if(!strcmp(av[1], "-timeout")) { timeout = atoi(av[2]); ac--; av++; }
       else if(!strcmp(av[1], "-epoc32_filesystem")){ series5 = 1; }
+      else if(!strcmp(av[1], "-nfsblock")) { nfsblock = atoi(av[2]); ac--;av++;}
 
       else if(!strcmp(av[1], "-series3")) { speed = 9600; arch_set = 1;  }
       else if(!strcmp(av[1], "-series3a")){ speed = 19200; arch_set = 1; }
@@ -114,6 +115,7 @@ main(ac, av)
 	  old_nfsc = 1;
 	  series5 = 1;
 	  arch_set = 1;
+	  nfsblock = 4096;
 	}
       else
 	{
@@ -127,6 +129,7 @@ main(ac, av)
 	  printf("   [-timeout <msec>]\n");
 	  printf("   [-oldnfsc] [-epoc32_filesystem]\n");
 	  printf("   [-conn <prog>] [-disconn <prog>] (if HW flowcontrol available)\n");
+	  printf("   [-nfsblock <NFS bloksize>]\n");
 #ifdef PTY
 	  printf("Series 3a client only with nfsc:\n");
 	  printf("   [-wakeup] [-shell prog]\n");
@@ -143,6 +146,7 @@ main(ac, av)
 	  if(soft_flow)       printf("  -softflow\n");
 	  if(no_flow)         printf("  -noflow\n");
 	  if(timeout)         printf("  -timeout %d\n", timeout);
+	  printf("  -nfsblock %d\n", nfsblock);
 	  return 1;
 	}
       ac--;av++;
