@@ -123,6 +123,7 @@ extern int _rpc_dtablesize();
 
 
 static char *mntdir;		/* where we mounted the psion */
+extern int nfsblock;
 
 #ifdef __STDC__
 static void doexit(void);
@@ -350,8 +351,8 @@ mount_and_run(dir, dev, proc, root_fh)
 #endif
   nfs_mount_data.flags   = NFS_MOUNT_INTR | NFS_MOUNT_NOCTO; 
   			/* NFS_MOUNT_SECURE | NFS_MOUNT_SOFT | NFS_MOUNT_NOAC */
-  nfs_mount_data.rsize    = PBUFSIZE;
-  nfs_mount_data.wsize    = PBUFSIZE;
+  nfs_mount_data.rsize    = nfsblock;
+  nfs_mount_data.wsize    = nfsblock;
   nfs_mount_data.timeo    = 600;
   nfs_mount_data.retrans  = 10;		/* default 3 */
   nfs_mount_data.acregmin = 3;		/* default 3 seconds */
@@ -403,8 +404,8 @@ mount_and_run(dir, dev, proc, root_fh)
     myaddr.buf=(char *)&sain;
 
     nfs_args.knconf   = &knc;
-    nfs_args.wsize    = PBUFSIZE;
-    nfs_args.rsize    = PBUFSIZE;
+    nfs_args.wsize    = nfsblock;
+    nfs_args.rsize    = nfsblock;
     nfs_args.addr     = &myaddr;
     nfs_args.fh       = (char *)root_fh;
     nfs_args.retrans  = 10;
@@ -422,8 +423,8 @@ mount_and_run(dir, dev, proc, root_fh)
 #if (defined(sun) && !defined(__SVR4))  || defined(hpux) || defined(__sgi) || defined(__NeXT__)
   nfs_args.addr     = &sain;
   nfs_args.fh       = (void *)root_fh;
-  nfs_args.wsize    = PBUFSIZE;
-  nfs_args.rsize    = PBUFSIZE;
+  nfs_args.wsize    = nfsblock;
+  nfs_args.rsize    = nfsblock;
   nfs_args.retrans = 10;
   /* 1 minute timeout - means that we receive double requests in worst case,
    if the file is longer than 100k. So long for the theory. Since SunOS uses
@@ -443,8 +444,8 @@ mount_and_run(dir, dev, proc, root_fh)
   nfs_args.sotype   = SOCK_DGRAM;
   nfs_args.fh       = (void *)root_fh;
   nfs_args.fhsize   = sizeof(*root_fh);
-  nfs_args.wsize    = PBUFSIZE;
-  nfs_args.rsize    = PBUFSIZE;
+  nfs_args.wsize    = nfsblock;
+  nfs_args.rsize    = nfsblock;
   nfs_args.retrans = 10;
   /* 1 minute timeout - see below */
   nfs_args.timeo = 600;
@@ -466,8 +467,8 @@ mount_and_run(dir, dev, proc, root_fh)
   nfs_args.readahead = 1 ;
   nfs_args.addr     = (struct sockaddr *)&sain;
   nfs_args.fh       = (void *)root_fh;
-  nfs_args.wsize    = PBUFSIZE;
-  nfs_args.rsize    = PBUFSIZE;
+  nfs_args.wsize    = nfsblock;
+  nfs_args.rsize    = nfsblock;
   nfs_args.retrans = 10;
   nfs_args.timeo = 600;
   nfs_args.hostname = PSIONHOSTNAME;
@@ -479,8 +480,8 @@ mount_and_run(dir, dev, proc, root_fh)
 #if defined(_IBMR2)
   nfs_args.addr     = sain;
   nfs_args.fh       = *(fhandle_t *)root_fh;
-  nfs_args.wsize    = PBUFSIZE;
-  nfs_args.rsize    = PBUFSIZE;
+  nfs_args.wsize    = nfsblock;
+  nfs_args.rsize    = nfsblock;
   nfs_args.retrans  = 0; /* Shouldn't need bigger retrans since there is
                             only one biod. Somebody prove it ? Nice feature. */
   nfs_args.biods    = 1;
