@@ -71,6 +71,10 @@ int fd, wake;
 {
   int w;
   mflag z;
+  extern int tcp;
+
+  if(tcp)
+    return 1;
 
   if (fd < 0) {
     if (debug > 2) printf("fd_is_alive: Checking on closed fd\n") ;
@@ -218,10 +222,10 @@ close_012()
 
 #ifdef __NeXT__
 int
-init_serial(dev, speed)
-  char *dev;
-  int speed;
+init_serial()
 {
+  extern char *dev;
+  extern int speed;
   int fd, baud, local;
   struct sgttyb ti;
   struct tchars        tchars;
@@ -260,10 +264,6 @@ init_serial(dev, speed)
   return fd;
 }
 
-/*
- * We want to put the tty line back like we found it. It may be that
- * NetBSD is the only supported OS that needs this done to it.
- */
 void
 reset_serial(fd)
 int fd;
@@ -273,10 +273,10 @@ int fd;
 #else /*__NeXT__*/
 
 int
-init_serial(dev, speed)
-  char *dev;
-  int speed;
+init_serial()
 {
+  extern char *dev;
+  extern int speed;
   int fd, baud, clocal;
   struct termios ti;
 #ifdef hpux
@@ -308,16 +308,26 @@ init_serial(dev, speed)
   bzero((char *)&ti, sizeof(struct termios));
 #if defined(hpux) || defined(_IBMR2)
   ti.c_cflag = CS8 | HUPCL | clocal | CREAD;
+#warning soft_flow not implemented
 #endif
 #if defined(sun) || defined(linux) || defined(__sgi) || defined(__NetBSD__) || defined(__FreeBSD__)
-  ti.c_cflag = CS8 | HUPCL | clocal | CRTSCTS | CREAD;
+  ti.c_cflag = CS8 | HUPCL | clocal | CREAD;
   ti.c_iflag = IGNBRK | IGNPAR;
+
+  if(soft_flow)
+    ti.c_iflag |= IXON|IXOFF;
+  else if(!no_flow)
+    ti.c_cflag |= CRTSCTS;
+
   ti.c_cc[VMIN] = 1;
   ti.c_cc[VTIME] = 0;
+  ti.c_cc[VSTART] = SOFTFLOW_RSTART;
+  ti.c_cc[VSTOP] = SOFTFLOW_RSTOP;
 #endif
   cfsetispeed(&ti, baud);
   cfsetospeed(&ti, baud);
 
+
   if(tcsetattr(fd, TCSADRAIN, &ti) < 0)
     perror("tcsetattr TCSADRAIN");
 
